@@ -45,7 +45,7 @@ class Client:
         self.local_headers = {}
         self.region = region
         self.shard = region
-        self.auth = {}
+        self.auth = None
 
         if auth is not None:
             self.auth = Auth(auth)
@@ -62,10 +62,15 @@ class Client:
 
         self.base_url, self.base_url_glz, self.base_url_shared = self.__build_urls()
 
+    def activate_from_headers(self,headers,puuid) -> None:
+        '''Activate the client if you already have headers''' 
+        self.headers = headers
+        self.puuid = puuid
+
     def activate(self) -> None:
         '''Activate the client and get authorization'''
         try:
-            if self.auth == {}:
+            if self.auth is None:
                 self.lockfile = self.__get_lockfile()
                 self.puuid, self.headers, self.local_headers = self.__get_headers()
                 
